Sybil
=====

|CircleCI|_ |Docs|_

.. |CircleCI| image:: https://circleci.com/gh/cjw296/sybil/tree/master.svg?style=shield
.. _CircleCI: https://circleci.com/gh/cjw296/sybil/tree/master

.. |Docs| image:: https://readthedocs.org/projects/sybil/badge/?version=latest
.. _Docs: http://sybil.readthedocs.org/en/latest/


This library provides a way to test examples in your documentation by parsing
them from the documentation source and evaluating the parsed examples as part of
your normal test run. Integration is provided for the main Python test
runners.
